@@ -1,6 +1,6 @@
 package Ubic::Credentials::OS::POSIX;
 {
-  $Ubic::Credentials::OS::POSIX::VERSION = '1.38';
+  $Ubic::Credentials::OS::POSIX::VERSION = '1.39';
 }
 
 use strict;
@@ -248,18 +248,25 @@ sub set {
     my @real_gid = $self->real_group_id;
     $( = $real_gid[0];
     unless ($self->_groups_equal($(, "@real_gid")) {
-        die "Failed to set real gid to @real_gid: $!";
-    }
-    my $new_euid = $self->effective_user_id;
-    $> = $new_euid;
-    unless ($> == $new_euid) {
-        die "Failed to set effective uid to $new_euid: $!";
+        die "Failed to set real gid to @real_gid: $! (\$( = $(, real_gid = @real_gid)";
     }
     my $new_ruid = $self->real_user_id;
     $< = $new_ruid;
     unless ($< == $new_ruid) {
         die "Failed to set real uid to $new_ruid: $!";
     }
+    my $new_euid = $self->effective_user_id;
+    $> = $new_euid;
+    unless ($> == $new_euid) {
+        die "Failed to set effective uid to $new_euid: $!";
+    }
+}
+
+sub as_string {
+    my $self = shift;
+    my $user = $self->user;
+    my ($group) = $self->group; # ignore complementary groups for the sake of readability
+    return "$user:$group";
 }
 
 
@@ -274,7 +281,7 @@ Ubic::Credentials::OS::POSIX - POSIX-specific credentials implementation
 
 =head1 VERSION
 
-version 1.38
+version 1.39
 
 =head1 METHODS
 
