@@ -1,6 +1,6 @@
 package Ubic::Lockf;
 {
-  $Ubic::Lockf::VERSION = '1.38';
+  $Ubic::Lockf::VERSION = '1.39';
 }
 
 use strict;
@@ -26,7 +26,7 @@ sub DESTROY ($) {
     my ($self) = @_;
     local $@;
     my $fh = $self->{_fh};
-    return unless defined $fh; # already released
+    return unless defined $fh; # already released or dissolved
     flock $fh, LOCK_UN;
     delete $self->{_fh}; # closes the file if opened by us
 }
@@ -107,10 +107,15 @@ sub _lockf ($$;$) {
 
 sub name($)
 {
-    my $self = shift();
+    my $self = shift;
     return $self->{_fname};
 }
 
+sub dissolve {
+    my $self = shift;
+    undef $self->{_fh};
+}
+
 1;
 
 
@@ -123,7 +128,7 @@ Ubic::Lockf - file locker with an automatic out-of-scope unlocking mechanism
 
 =head1 VERSION
 
-version 1.38
+version 1.39
 
 =head1 SYNOPSIS
 
@@ -175,6 +180,12 @@ Undef by default. If set, a chmod with the specified mode is performed on a newl
 
 Gives the name of the file, as it was when the lock was taken.
 
+=item B<dissolve()>
+
+Destroy lock object without unlocking.
+
+This is useful in forking code, if you have one lock object in several processes and want to close locked fh in one process without unlocking in the other.
+
 =back
 
 =head1 AUTHOR
